import auth
import admin

# 欢迎界面
welcome = ["===========================",
           "欢迎使用图书馆借阅管理系统",
           "1 注册",
           "2 登录",
           "3 退出系统",
           "==========================="]
for i in welcome:
    print("%s" % i.center(18, "　"))

while True:
    flag = input("请输入（1、2 或 3）选择系统功能:")
    if flag == "1":
        auth.register()
    elif flag == "2":
        user, is_admin = auth.login()
        if user:
            if is_admin:
                admin.admin_menu()
            else:
                print("普通用户登录成功，暂无其他操作，可选择退出系统。")
    elif flag == "3":
        print("感谢使用，再见！")
        break
    else:
        print("请输入有效的数字（1、2 或 3）！")



from setuptools import setup, find_packages

setup(
    name='abandon_gard_library_management_sytm',
    version='1.0.0',
    description='A library management system with user registration, login, and admin functions.',
    author='Your Name',
    author_email='your_email@example.com',
    packages=find_packages(),
    install_requires=[
        # 列出项目依赖的第三方库，如果有
    ],
    entry_points={
        'console_scripts': [
            'library - management - system = library_management_system.main:main',
        ],
    },
)


from auth import vip_info, vip_name


def add_user():
    print("开始添加用户")
    while True:
        reg_name = input("请输入新用户的用户名：\n")
        if reg_name in vip_name:
            print('该用户名已被注册！')
        else:
            break
    while True:
        reg_psw = input("请输入新用户的密码：\n")
        if len(reg_psw) < 6:
            print('密码太简单!密码长度应为为6 - 18位!，请重新输入：')
            continue
        elif reg_psw.isalpha() or reg_psw.isdigit():
            print("请不要使用纯字母或纯数字密码，应该为数字字母混合密码，请重新输入：")
            continue
        else:
            person_info = {'name': reg_name, 'psw': reg_psw, 'is_admin': False}
            vip_info.append(person_info)
            vip_name.append(reg_name)
            print("用户添加成功。")
            break


def delete_user():
    print("开始删除用户")
    user_name = input("请输入要删除的用户的用户名：\n")
    if user_name in vip_name:
        index = vip_name.index(user_name)
        del vip_info[index]
        vip_name.remove(user_name)
        print("用户删除成功。")
    else:
        print("该用户不存在。")


def modify_user():
    print("开始修改用户信息")
    user_name = input("请输入要修改信息的用户的用户名：\n")
    if user_name in vip_name:
        index = vip_name.index(user_name)
        new_psw = input("请输入新的密码（不修改请直接回车）：\n")
        if new_psw:
            vip_info[index]['psw'] = new_psw
            print("用户密码修改成功。")
    else:
        print("该用户不存在。")


def display_users():
    print("当前系统内的用户信息如下：")
    for user in vip_info:
        print(f"用户名：{user['name']}")


def admin_menu():
    while True:
        print("=" * 20)
        print("管理员用户信息维护菜单：")
        print("1. 添加用户")
        print("2. 删除用户")
        print("3. 修改用户信息")
        print("4. 显示用户信息")
        print("5. 退出维护菜单")
        choice = input("请输入您的选择（1 - 5）：")
        if choice == '1':
            add_user()
        elif choice == '2':
            delete_user()
        elif choice == '3':
            modify_user()
        elif choice == '4':
            display_users()
        elif choice == '5':
            print("退出用户信息维护菜单。")
            break
        else:
            print("输入无效，请输入 1 - 5 之间的数字。")



import msvcrt



# 密码加密显示
def jiami():
    print('请输入密码: ')
    li = []
    while True:
        ch = msvcrt.getch()
        if ch == b'\r':  # 回车
            break
        elif ch == b'\x08':  # 退格
            if li:
                li.pop()
                msvcrt.putch(b'\b')
                msvcrt.putch(b' ')
                msvcrt.putch(b'\b')
        # Esc
        elif ch == b'\x1b':
            break
        else:
            li.append(ch)
            msvcrt.putch(b'*')
    return b''.join(li).decode()


def register():
    print("开始进行用户注册")
    while True:
        reg_name = input("请输入注册用户名：\n")
        for i in sensitive_character:
            if i in reg_name:
                reg_name = reg_name.replace(i, '*')
                print("用户名包含非法字{}，请重新输入。".format(reg_name))
                break
        else:
            if reg_name in vip_name:
                print('该用户名已被注册！')
            else:
                break

    while True:
        reg_psw = jiami()
        if len(reg_psw) < 6:
            print('密码太简单!密码长度应为为6 - 18位!，请重新输入：')
            continue
        elif reg_psw.isalpha() or reg_psw.isdigit():
            print("请不要使用纯字母或纯数字密码，应该为数字字母混合密码，请重新输入：")
            continue
        else:
            person_info = {'name': reg_name, 'psw': reg_psw, 'is_admin': False}
            vip_info.append(person_info)
            vip_name.append(reg_name)
            print("恭喜，注册成功。")
            break


def login():
    print("开始进行用户登录")
    log_conut1 = 3
    while log_conut1:
        log_name = input("请输入用户名：\n")
        if log_name not in vip_name:
            log_conut1 -= 1
            print("用户名不存在，您还要{}次试错机会。".format(log_conut1))
            continue
        else:
            conut_log2 = 3
            while conut_log2:
                conut_log2 -= 1
                cur_index = vip_name.index(log_name)
                log_psw = jiami()
                if log_psw == vip_info[cur_index]['psw']:
                    print('登录成功!')
                    return vip_info[cur_index], vip_info[cur_index]['is_admin']
                else:
                    print("密码输入不正确。您还有{}次试错机会。".format(conut_log2))
    print("登录失败，试错机会已用完。")
    return None, False
# vip_info  系统内已注册用户信息表
vip_info = [
    {'name': '张三', 'psw': 'zs333333', 'is_admin': False},
    {'name': '李四', 'psw': 'ls444444', 'is_admin': False},
    {'name': 'admin', 'psw': 'admin123', 'is_admin': True}  # 管理员用户
]

# 用户名列表
vip_name = [vip_info[i]["name"] for i in range(len(vip_info))]

# 建立敏感词库
sensitive_character = ["傻", "屁", "草", "操", "垃圾", "z"]
